Susan Shepler - Google Scholar Citations

Loading...
The system can't perform the operation now. Try again later.

## Citations per year

## Duplicate citations

The following articles are merged in Scholar. Their combined citations are counted only for the first article.

## Merged citations

This "Cited by" count includes citations to the following articles in Scholar. The ones marked * may be different from the article in the profile.

## Add co-authorsCo-authors

##
Upload PDF

## Follow this author

New articles by this author
New citations to this author
New articles related to this author's research
Email address for updates
My profile My library Metrics Alerts
Settings
teals.alan.cooper@gmail.com
Alan Cooper
teals.alan.cooper@gmail.com
Susan Shepler
Associate Professor, School of International Service, American University.
Verified email at american.edu - Homepage
Sierra Leone child soldiers youth and conflict education and development Ebola

Title Sort by citations Sort by year Sort by title | Cited by Cited by | Year
The rites of the child: Global discourses of youth and reintegrating child soldiers in Sierra Leone S Shepler Journal of Human Rights 4 (2), 197-211, 2005 | 156 | 2005
Childhood deployed: Remaking child soldiers in Sierra Leone S Shepler NYU Press, 2014 | 64 | 2014
The social and cultural context of child soldiering in Sierra Leone S Shepler PRIO-sponsored Workshop on Techniques of Violence in Civil War, Oslo, 2004 | 58 | 2004
Conflicted childhoods: Fighting over child soldiers in Sierra Leone SA Shepler University of California, Berkeley, 2005 | 57 | 2005
Les filles-soldats: Trajectoires d'apres-guerre en Sierra Leone S Shepler Politique africaine 88 (4), 49-62, 2002 | 53* | 2002
Youth music and politics in post-war Sierra Leone S Shepler The Journal of Modern African Studies 48 (4), 627-642, 2010 | 41 | 2010
Fears and misperceptions of the Ebola response system during the 2014-2015 outbreak in Sierra Leone T Yamanis, E Nolan, S Shepler PLoS neglected tropical diseases 10 (10), 2016 | 36 | 2016
Conflict resolution and peace education in Africa IM Schwartz, R Acholonu, GN Ayittey, R Dibie, K Kalu, C Bakwesegha, ... Lexington Books, 2003 | 28 | 2003
Introduction to Special Issue: Everyday Life in Postwar Sierra Leone AF Ibrahim, S Shepler Africa Today 58 (2), v-xii, 2011 | 26* | 2011
Globalizing Child Soldiers in Sierra Leone S Shepler Youthscapes: The Popular, The National, The Global, 119-133, 2004 | 25 | 2004
"We Know Who is Eating the Ebola Money!": Corruption, the State, and the Ebola Response S Shepler Anthropological Quarterly 90 (2), 451-473, 2017 | 22 | 2017
The real and symbolic importance of food in war: hunger pains and big men's bellies in Sierra Leone S Shepler Africa Today 58 (2), 43-56, 2011 | 18 | 2011
Human rights in Sierra Leone: A research report to Search for Common Ground A Abdalla, S Hussein, S Shepler Washington, DC: Search for Common Ground, 2002 | 14* | 2002
Understanding Sierra Leonean and Liberian teachers’ views on discussing past wars in their classrooms S Shepler, JH Williams Comparative education 53 (3), 418-441, 2017 | 11 | 2017
Effects in post-conflict West Africa of teacher training for refugee women S Shepler, S Routh Gender and Education 24 (4), 429-441, 2012 | 10 | 2012
Are 'Child Soldiers' in Sierra Leone a New Phenomenon? S Shepler The Powerful Presence of the Past: Integration and Conflict along the Upper …, 2010 | 10 | 2010
The Ebola Virus and the Vampire State S Shepler https://matsutas.wordpress.com/2014/07/21/the-ebola-virus-and-the-vampire …, 2014 | 9 | 2014
“Helping our children will help in the reconstruction of our country”: Repatriated Refugee Teachers in post-conflict Sierra Leone and Liberia S Shepler Educating Children in Conflict Zones: Research, Policy, and Practice for …, 2011 | 9 | 2011
Educated in War: The Rehabilitation of Child Soldiers in Sierra Leone S Shepler Conflict Resolution and Peace Education in Africa, 57-76, 2003 | 9 | 2003
Producing ebola: creating knowledge in and about an epidemic C Bolten, S Shepler Anthropological Quarterly 90 (2), 349-368, 2017 | 8 | 2017

The system can't perform the operation now. Try again later.
Articles 1–20